@@ -6,12 +6,14 @@ from .ntuser.typed_urls import TypedUrlsPlugin
 from .ntuser.installed_programs_ntuser import InstalledSoftwareNTUserPlugin
 from .ntuser.tsclient import TSClientPlugin
 from .ntuser.classes_installer import ClassesInstallerPlugin
+from .ntuser.winrar import WinRARPlugin
 from .system.bam import BAMPlugin
 from .system.routes import RoutesPlugin
 from .system.services import ServicesPlugin
 from .system.computer_name import ComputerNamePlugin
 from .system.shimcache import ShimCachePlugin
 from .system.safeboot_configuration import SafeBootConfigurationPlugin
+from .system.wdigest import WDIGESTPlugin
 from .software.tracing import RASTracingPlugin
 from .software.classes_installer import SoftwareClassesInstallerPlugin
 from .software.installed_programs import InstalledSoftwarePlugin
